@@ -14,6 +14,8 @@
  * limitations under the License.
  */
 
+#include "charmony.h"
+
 #include "Lucy/Util/ProcessID.h"
 
 /********************************* WINDOWS ********************************/
@@ -27,7 +29,7 @@ lucy_PID_getpid(void) {
     return GetCurrentProcessId();
 }
 
-chy_bool_t
+bool
 lucy_PID_active(int pid) {
     // Attempt to open a handle to the process with permissions to terminate
     // -- but don't actually terminate.
@@ -61,7 +63,7 @@ lucy_PID_getpid(void) {
     return getpid();
 }
 
-chy_bool_t
+bool
 lucy_PID_active(int pid) {
     if (kill(pid, 0) == 0) {
         return true; // signal succeeded, therefore pid active
